@@ -8,6 +8,7 @@ import (
 	"crypto/tls"
 	"crypto/x509"
 	"encoding/json"
+	stderr "errors"
 	"fmt"
 	"io"
 	"net"
@@ -97,6 +98,9 @@ type Handler interface {
 
 // Server is the GRPC server that the launched applications connect back to.
 type Server struct {
+	// Disable forward compatibility
+	*proto.UnimplementedElasticAgentServer
+
 	logger     *logger.Logger
 	ca         *authority.CertificateAuthority
 	listenAddr string
@@ -122,13 +126,14 @@ func New(logger *logger.Logger, listenAddr string, handler Handler) (*Server, er
 		return nil, err
 	}
 	return &Server{
-		logger:                logger,
-		ca:                    ca,
-		listenAddr:            listenAddr,
-		handler:               handler,
-		serverLock:            &sync.Mutex{},
-		watchdogCheckInterval: WatchdogCheckLoop,
-		checkInMinTimeout:     client.CheckinMinimumTimeout + CheckinMinimumTimeoutGracePeriod,
+		UnimplementedElasticAgentServer: &proto.UnimplementedElasticAgentServer{},
+		logger:                          logger,
+		ca:                              ca,
+		listenAddr:                      listenAddr,
+		handler:                         handler,
+		serverLock:                      &sync.Mutex{},
+		watchdogCheckInterval:           WatchdogCheckLoop,
+		checkInMinTimeout:               client.CheckinMinimumTimeout + CheckinMinimumTimeoutGracePeriod,
 	}, nil
 }
 
@@ -148,6 +153,7 @@ func (s *Server) Start() error {
 	if ok := certPool.AppendCertsFromPEM(s.ca.Crt()); !ok {
 		return errors.New("failed to append root CA", errors.TypeSecurity)
 	}
+	//nolint:gosec // FIXME: https://github.com/elastic/ingest-dev/issues/3474
 	creds := credentials.NewTLS(&tls.Config{
 		ClientAuth:     tls.RequireAndVerifyClientCert,
 		ClientCAs:      certPool,
@@ -544,7 +550,7 @@ func (s *Server) Actions(server proto.ElasticAgent_ActionsServer) error {
 //
 // Note: If the writer implements io.Closer the writer is also closed.
 func (as *ApplicationState) WriteConnInfo(w io.Writer) error {
-	connInfo := &proto.ConnInfo{
+	connInfo := &proto.StartUpInfo{
 		Addr:       as.srv.getListenAddr(),
 		ServerName: as.srvName,
 		Token:      as.token,
@@ -980,7 +986,7 @@ type actionResult struct {
 }
 
 func reportableErr(err error) bool {
-	if err == io.EOF {
+	if stderr.Is(err, io.EOF) {
 		return false
 	}
 	s, ok := status.FromError(err)
